<#ibiztemplate>
TARGET=PSSYSTEM
</#ibiztemplate>
<?xml version="1.0" encoding="UTF-8"?>
<project xmlns="http://maven.apache.org/POM/4.0.0"
         xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
         xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
    <modelVersion>4.0.0</modelVersion>

    <artifactId>${pub.getCodeName()?lower_case}-dependencies</artifactId>
    <groupId>${pub.getPKGCodeName()?lower_case}</groupId>
    <version>${pub.getVersionString()?default("V0.0.1_alpha")}</version>
    <name>${pub.getCodeName()?lower_case?cap_first} Dependencies</name>
    <packaging>pom</packaging>
    <description>${pub.getCodeName()?lower_case?cap_first} Dependencies</description>

    <!--  Spring Boot -->
    <parent>
        <groupId>org.springframework.boot</groupId>
        <artifactId>spring-boot-starter-parent</artifactId>
        <version>2.2.1.RELEASE</version>
    </parent>

    <#--  properties, usually record jars version constants  -->
    <properties>
        <!--  Spring Cloud Alibaba(2.1.x.RELEASE) & Spring Cloud(Spring Cloud Greenwich) & Spring Boot(2.1.x.RELEASE) compatibility -->
        <spring-cloud-alibaba.version>2.1.1.RELEASE</spring-cloud-alibaba.version>

        <spring-cloud-openfeign.version>2.2.1.RELEASE</spring-cloud-openfeign.version>

        <!--  Alibaba Druid  -->
        <alibaba-druid.version>1.1.16</alibaba-druid.version>

        <!--  Mybatis Plus -->
        <mybatis-plus.version>3.0.6</mybatis-plus.version>
        <mybatis-plus-dynamic-datasource.version>2.5.4</mybatis-plus-dynamic-datasource.version>

        <!--  Liquibase -->
        <liquibase.version>3.6.3</liquibase.version>

        <!--  Swagger2 -->
        <springfox-swagger.version>2.9.2</springfox-swagger.version>

        <!--  JBPM+Drools -->
        <drools-version>7.23.0.Final</drools-version>

        <!--  Error -->
        <zalando-problem-spring-web.version>0.23.0</zalando-problem-spring-web.version>

        <!--  Security  -->
        <spring-cloud-security.version>2.1.1.RELEASE</spring-cloud-security.version>

        <!--  Activity  -->
        <activiti.version>7.1.0.M2</activiti.version>

        <maven-jar-plugin.version>3.1.1</maven-jar-plugin.version>
        <!--logstash-logback-encoder-->
        <logstash.version>5.2</logstash.version>
    </properties>

    <#--  dependencies,just for statement, manage the version of jars   -->
    <dependencyManagement>
        <dependencies>
            <!--  Alibaba Cloud -->
            <dependency>
                <groupId>com.alibaba.cloud</groupId>
                <artifactId>spring-cloud-alibaba-dependencies</artifactId>
                <version>${r'${spring-cloud-alibaba.version}'}</version>
                <type>pom</type>
                <scope>import</scope>
            </dependency>

            <!--  Spring Cloud -->
            <dependency>
                <groupId>org.springframework.cloud</groupId>
                <artifactId>spring-cloud-openfeign-dependencies</artifactId>
                <version>${r'${spring-cloud-openfeign.version}'}</version>
                <type>pom</type>
                <scope>import</scope>
            </dependency>

            <!--  Alibaba Druid -->
            <dependency>
                <groupId>com.alibaba</groupId>
                <artifactId>druid</artifactId>
                <version>${r'${alibaba-druid.version}'}</version>
            </dependency>
            <dependency>
                <groupId>com.alibaba</groupId>
                <artifactId>druid-spring-boot-starter</artifactId>
                <version>${r'${alibaba-druid.version}'}</version>
            </dependency>

            <!--  Mybatis Plus  -->
            <dependency>
                <groupId>com.baomidou</groupId>
                <artifactId>mybatis-plus-boot-starter</artifactId>
                <version>${r'${mybatis-plus.version}'}</version>
            </dependency>
            <dependency>
                <groupId>com.baomidou</groupId>
                <artifactId>dynamic-datasource-spring-boot-starter</artifactId>
                <version>${r'${mybatis-plus-dynamic-datasource.version}'}</version>
            </dependency>

            <!--  Liquibase  -->
            <dependency>
                <groupId>org.liquibase</groupId>
                <artifactId>liquibase-core</artifactId>
                <version>${r'${liquibase.version}'}</version>
            </dependency>

            <!--  Swagger2  -->
            <dependency>
                <groupId>io.springfox</groupId>
                <artifactId>springfox-swagger2</artifactId>
                <version>${r'${springfox-swagger.version}'}</version>
            </dependency>
            <dependency>
                <groupId>io.springfox</groupId>
                <artifactId>springfox-swagger-ui</artifactId>
                <version>${r'${springfox-swagger.version}'}</version>
            </dependency>

            <!--  JBPM  -->
            <dependency>
                <groupId>org.jbpm</groupId>
                <artifactId>jbpm-flow-builder</artifactId>
                <version>${r'${drools-version}'}</version>
            </dependency>
            <dependency>
                <groupId>org.jbpm</groupId>
                <artifactId>jbpm-bpmn2</artifactId>
                <version>${r'${drools-version}'}</version>
            </dependency>

            <!--  Drools  -->
            <dependency>
                <groupId>org.drools</groupId>
                <artifactId>drools-compiler</artifactId>
                <version>${r'${drools-version}'}</version>
            </dependency>
            <dependency>
                <groupId>org.drools</groupId>
                <artifactId>drools-core</artifactId>
                <version>${r'${drools-version}'}</version>
            </dependency>
            <dependency>
                <groupId>org.kie</groupId>
                <artifactId>kie-spring</artifactId>
                <version>${r'${drools-version}'}</version>
            </dependency>
            <dependency>
                <groupId>org.kie</groupId>
                <artifactId>kie-api</artifactId>
                <version>${r'${drools-version}'}</version>
            </dependency>

            <!-- Activiti -->
            <dependency>
                <groupId>org.activiti</groupId>
                <artifactId>activiti-spring-boot-starter</artifactId>
                <version>${r'${activiti.version}'}</version>
            </dependency>
            <dependency>
                <groupId>org.activiti</groupId>
                <artifactId>activiti-json-converter</artifactId>
                <version>${r'${activiti.version}'}</version>
            </dependency>
            <dependency>
                <groupId>org.activiti</groupId>
                <artifactId>activiti-image-generator</artifactId>
                <version>${r'${activiti.version}'}</version>
            </dependency>

            <!--  Error  -->
            <#--<dependency>-->
                <#--<groupId>org.zalando</groupId>-->
                <#--<artifactId>problem-spring-web</artifactId>-->
                <#--<version>${r'${zalando-problem-spring-web.version}'}</version>-->
            <#--</dependency>-->

            <!--  Security  -->
            <#--<dependency>-->
                <#--<groupId>org.springframework.cloud</groupId>-->
                <#--<artifactId>spring-cloud-starter-security</artifactId>-->
                <#--<version>${r'${spring-cloud-security.version}'}</version>-->
            <#--</dependency>-->
            <dependency>
                <groupId>net.logstash.logback</groupId>
                <artifactId>logstash-logback-encoder</artifactId>
                <version>${r'${logstash.version}'}</version>
            </dependency>
        </dependencies>
    </dependencyManagement>


    <dependencies>
        <!--  Spring Boot -->
        <dependency>
            <groupId>org.springframework.boot</groupId>
            <artifactId>spring-boot-starter-web</artifactId>
        </dependency>

        <!--  Spring Cloud -->
        <dependency>
            <groupId>org.springframework.cloud</groupId>
            <artifactId>spring-cloud-starter-openfeign</artifactId>
        </dependency>

        <!--  Alibaba Nacos -->
        <dependency>
            <groupId>com.alibaba.cloud</groupId>
            <artifactId>spring-cloud-starter-alibaba-nacos-discovery</artifactId>
        </dependency>

        <!--  Alibaba Sentinel -->
        <dependency>
            <groupId>com.alibaba.cloud</groupId>
            <artifactId>spring-cloud-starter-alibaba-sentinel</artifactId>
        </dependency>

        <!--  Lombok -->
        <dependency>
            <groupId>org.projectlombok</groupId>
            <artifactId>lombok</artifactId>
        </dependency>

        <!--  Httpclient -->
        <dependency>
            <groupId>org.apache.httpcomponents</groupId>
            <artifactId>httpclient</artifactId>
        </dependency>

        <!--  Error -->
    <#--<dependency>-->
    <#--<groupId>org.zalando</groupId>-->
    <#--<artifactId>problem-spring-web</artifactId>-->
    <#--</dependency>-->

        <!--  Security  -->
    <#--<dependency>-->
    <#--<groupId>org.springframework.cloud</groupId>-->
    <#--<artifactId>spring-cloud-starter-security</artifactId>-->
    <#--</dependency>-->

    </dependencies>

</project>
